-- author  igor29381
-- v1.1
-- date  30.07.2018
--
AnimatedPart = {};

function AnimatedPart.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(AnimatedVehicle, specializations);
end

function AnimatedPart:load(savegame)
    self.setState = AnimatedPart.setState;
	self.animatedPart = {};
    self.animatedPart.animation = getXMLString(self.xmlFile, "vehicle.animatedPart#animationName");
	self.animatedPart.text = {};
	local startText = getXMLString(self.xmlFile, "vehicle.animatedPart#startText");
	local backText = getXMLString(self.xmlFile, "vehicle.animatedPart#backText");
	self.animatedPart.text[true] = g_i18n:getText(backText);
	self.animatedPart.text[false] = g_i18n:getText(startText);
	local inputButtonStr = Utils.getNoNil(getXMLString(self.xmlFile, "vehicle.animatedPart#inputButton"), "TOGGLE_COVER");
	if inputButtonStr then
		self.animatedPart.inputButton = InputBinding[inputButtonStr];
	end;
	self.animatedPart.state = false;
end;

function AnimatedPart:postLoad(savegame)
	if savegame then
		local state = getXMLBool(savegame.xmlFile, savegame.key.."#animPartState");
		self:setState(state);
	end;
end;

function AnimatedPart:getSaveAttributesAndNodes(nodeIdent)
    local attributes = 'animPartState="'..tostring(self.animatedPart.state)..'"';
	return attributes, nil;
end

function AnimatedPart:delete()
end

function AnimatedPart:mouseEvent(posX, posY, isDown, isUp, button)
end

function AnimatedPart:keyEvent(unicode, sym, modifier, isDown)
end

function AnimatedPart:readStream(streamId, connection)
    if connection:getIsServer() then
        if self.animatedPart.animation then
            local state = streamReadBool(streamId);
            self:setState(state);
        end
    end
end

function AnimatedPart:writeStream(streamId, connection)
    if not connection:getIsServer() then
        if self.animatedPart.animation then
            streamWriteBool(streamId, self.animatedPart.state);
        end;
    end;
end;

function AnimatedPart:update(dt)
    if self:getIsActiveForInput() then
        if self.animatedPart.animation then
            if InputBinding.hasEvent(self.animatedPart.inputButton) then
				if self.isServer then
					local state = not self.animatedPart.state;
					self:setState(state);
					g_server:broadcastEvent(AnimatedPartEvent:new(state, self));
				else
					g_client:getServerConnection():sendEvent(AnimatedPartEvent:new(not self.animatedPart.state, self));
				end;
            end;
        end;
    end;
end;

function AnimatedPart:draw()
    if self.isClient and self:getIsActiveForInput(true) then
        if self.animatedPart.animation then
			g_currentMission:addHelpButtonText(self.animatedPart.text[self.animatedPart.state], self.animatedPart.inputButton, nil, GS_PRIO_NORMAL);
        end;
    end;
end;

function AnimatedPart:setState(state)
    if self.animatedPart.animation then
        self.animatedPart.state = state;
        if state then
            self:playAnimation(self.animatedPart.animation, 1, self:getAnimationTime(self.animatedPart.animation), true);
        else
			self:playAnimation(self.animatedPart.animation, -1, self:getAnimationTime(self.animatedPart.animation), true);
        end;
    end;
end;

AnimatedPartEvent = {};
AnimatedPartEvent_mt = Class(AnimatedPartEvent, Event);
InitEventClass(AnimatedPartEvent, "AnimatedPartEvent");

function AnimatedPartEvent:emptyNew()
	local self = Event:new(AnimatedPartEvent_mt);
    return self;
end;

function AnimatedPartEvent:new(state, object)
	local self = AnimatedPartEvent:emptyNew();
	self.state = state;
	self.object = object;
	return self;
end;

function AnimatedPartEvent:readStream(streamId, connection)
	local state = streamReadBool(streamId);
    local object = networkGetObject(streamReadInt32(streamId));
	object:setState(state);
	if g_server then
		g_server:broadcastEvent(AnimatedPartEvent:new(state, object));
	end;
end;

function AnimatedPartEvent:writeStream(streamId, connection)
	streamWriteBool(streamId, self.state);
	streamWriteInt32(streamId, networkGetObjectId(self.object));
end;
